@@ -7,7 +7,7 @@ from v2ray_util import run_type
 from ..util_core.v2ray import restart
 from ..util_core.writer import StreamWriter, GroupWriter
 from ..util_core.selector import GroupSelector, CommonSelector
-from ..util_core.utils import StreamType, header_type_list, ColorStr, all_port, xtls_flow
+from ..util_core.utils import StreamType, header_type_list, ColorStr, all_port, xtls_flow, readchar
 
 from .ss import SSFactory
 
@@ -28,10 +28,17 @@ class StreamModifier:
             (StreamType.MTPROTO, "MTProto"), 
             (StreamType.SS, "Shadowsocks"),
             (StreamType.QUIC, "Quic"),
+            (StreamType.VLESS_KCP, "VLESS + mkcp"),
+            (StreamType.VLESS_UTP, "VLESS + mKCP + utp"),
+            (StreamType.VLESS_SRTP, "VLESS + mKCP + srtp"),
+            (StreamType.VLESS_WECHAT, "VLESS + mKCP + wechat-video"),
+            (StreamType.VLESS_DTLS, "VLESS + mKCP + dtls"),
+            (StreamType.VLESS_WG, "VLESS + mKCP + wireguard"),
             (StreamType.VLESS_TCP, "VLESS_TCP"),
             (StreamType.VLESS_TLS, "VLESS_TLS"),
             (StreamType.VLESS_WS, "VLESS_WS"),
             (StreamType.VLESS_XTLS, "VLESS_XTLS"),
+            (StreamType.VLESS_GRPC, "VLESS_GRPC"),
             (StreamType.TROJAN, "Trojan"),
         ]
         self.group_tag = group_tag
@@ -67,7 +74,7 @@ class StreamModifier:
             print("")
             header = CommonSelector(header_type_list(), _("please select fake header: ")).select()
             kw = {'security': security, 'key': key, 'header': header}
-        elif sType in (StreamType.VLESS_TLS, StreamType.VLESS_WS, StreamType.VLESS_XTLS):
+        elif sType in (StreamType.VLESS_TLS, StreamType.VLESS_WS, StreamType.VLESS_XTLS, StreamType.VLESS_GRPC):
             port_set = all_port()
             if not "443" in port_set:
                 print()
@@ -83,6 +90,11 @@ class StreamModifier:
                 print("")
                 flow = CommonSelector(flow_list, _("please select xtls flow type: ")).select()
                 kw = {'flow': flow}
+            elif sType == StreamType.VLESS_GRPC and run_type == "xray":
+                choice = readchar(_("open xray grpc multiMode?(y/n): ")).lower()
+                if choice == 'y':
+                    kw = {'mode': 'multi'}
+                
         elif sType == StreamType.TROJAN:
             port_set = all_port()
             if not "443" in port_set:
@@ -139,7 +151,7 @@ def modify(group=None, sType=None):
         else:
             choice = int(choice)
             if choice > 0 and choice <= len(sm.stream_type):
-                if sm.stream_type[choice - 1][1] in ("MTProto", "Shadowsocks") and group.tls == 'tls':
+                if sm.stream_type[choice - 1][1] in ("MTProto", "Shadowsocks") and group.tls in ('tls', 'xtls'):
                     print(_("{} MTProto/Shadowsocks not support https, close tls success!".format(run_type.capitalize())))
                 sm.select(sm.stream_type[choice - 1][0])
                 print(_("modify protocol success"))
