@@ -67,9 +67,16 @@ class StreamType(Enum):
     KCP_DTLS = 'dtls'
     KCP_WECHAT = 'wechat'
     KCP_WG = 'wireguard'
+    VLESS_KCP = 'vless_kcp'
+    VLESS_UTP = 'vless_utp'
+    VLESS_SRTP = 'vless_srtp'
+    VLESS_DTLS = 'vless_dtls'
+    VLESS_WECHAT = 'vless_wechat'
+    VLESS_WG = 'vless_wireguard'
     VLESS_TCP = 'vless_tcp'
     VLESS_TLS = 'vless_tls'
     VLESS_WS = 'vless_ws'
+    VLESS_GRPC = 'vless_grpc'
     VLESS_XTLS = 'vless_xtls'
     TROJAN = 'trojan'
 
@@ -193,6 +200,8 @@ def gen_cert(domain):
             os.system("curl https://get.acme.sh | sh")
 
     open_port(80)
+    if int(os.popen("/root/.acme.sh/acme.sh -v|tr -cd '[0-9]'").read()) >= 300:
+        os.system("/root/.acme.sh/acme.sh --set-default-ca --server letsencrypt")
     get_ssl_cmd = "bash /root/.acme.sh/acme.sh --issue -d " + domain + " --debug --standalone --keylength ec-256"
     if ":" in local_ip:
         get_ssl_cmd = get_ssl_cmd + " --listen-v6"
